Welcome to psychopy_ext documentation! — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext

A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology.

`pip install psychopy_ext`

Download Learn more

## Build

Experiments, analyses, and simulations:

all built-in, all running instantly.

## Publish

Quick statistics and publication quality plots.

## Share

Reproducibility as simple as a button click.

# Features:

## Object-oriented

Many experiments share a common structure. Why not start from a template (a class) that you can reuse? Many useful routines are built-in: experiment loop, automatic testing, data and log handling...

## Simple interface

A GUI is generated on the fly based on your project. Run and reproduce everything with ease! Command-line ninjas get their interface too.

## Neat project organization

All project materials have a clear organization and naming conventions. No more mess.

## Simple descriptive statistics

Compute accuracy across participants with a single command.

## Pretty plots

Instantly produce nice plots with a single command.

## Simulations

Are there simple confounds in your stimuli that could explain your findings? psychopy_ext has pixelwise, GaborJet, and HMAX'99 models built-in for a quick check.

# But aren't PsychoPy, matplotlib, pandas, ... sufficient?

Unlike PsychoPy, matplotlib, or pandas that are very flexible and support multiple options to suit everyone’s needs, the underlying philosophy of psychopy_ext is to act as the glue at a higher level of operation by choosing reasonable defaults for these packages and providing patterns for common tasks with a minimal user intervention. (read more...)

# I don't get it.

Prefer an academic explanation instead? (open access)

Kubilius, J. (2014). A framework for streamlining research workflow in neuroscience and psychology. Frontiers in Neuroinformatics, 7, 52. doi: 10.3389/fninf.2013.00052